@@ -24,15 +24,17 @@ js_edit_opts = {"require_save": True, "extension": ".json"}
 @click.group()
 @click.option("-h", "--host", default="localhost", help="MongoDB host.")
 @click.option("-p", "--port", default=27017, help="MongoDB port.")
-@click.option("-d", "--database", help="Database name.")
+@click.option("-d", "--database", default=False, help="Database name.")
 @click.option("-c", "--collection", help="Collection.")
 @click.pass_context
 def cli(ctx, host, port, database, collection):
     ctx.ensure_object(dict)
     cl = pymongo.MongoClient(host=host, port=port)
-    if database:
+    if database and collection:
         db = cl[database]
         ctx.obj["Collection"] = db[collection]
+    else:
+        raise click.ClickException("Database and collection should be set")
     ctx.obj["MongoClient"] = cl
 
 
@@ -87,7 +89,7 @@ def show_doc(ctx, document_id, document_object_id, flatten):
     elif document_object_id:
         filt = {"_id": ObjectId(document_object_id)}
     else:
-        raise RuntimeError(
+        raise click.ClickException(
             "Either --document-object-id or\
                             --document-id should be set"
         )
@@ -135,7 +137,7 @@ def edit_doc(ctx, document_id, document_object_id):
     elif document_object_id:
         filt = {"_id": ObjectId(document_object_id)}
     else:
-        raise RuntimeError(
+        raise click.ClickException(
             "Either --document-object-id or\
                             --document-id should be set"
         )
@@ -165,7 +167,7 @@ def del_doc(ctx, document_id, document_object_id):
     elif document_object_id:
         filt = {"_id": ObjectId(document_object_id)}
     else:
-        raise RuntimeError(
+        raise click.ClickException(
             "Either --document-object-id or\
                             --document-id should be set"
         )
